@@ -1,31 +1,5 @@
-/****************************************************************************
-**
-** Copyright (C) 2017 The Qt Company Ltd.
-** Contact: https://www.qt.io/licensing/
-**
-** This file is part of the Qt Network Auth module of the Qt Toolkit.
-**
-** $QT_BEGIN_LICENSE:GPL$
-** Commercial License Usage
-** Licensees holding valid commercial Qt licenses may use this file in
-** accordance with the commercial license agreement provided with the
-** Software or, alternatively, in accordance with the terms contained in
-** a written agreement between you and The Qt Company. For licensing terms
-** and conditions see https://www.qt.io/terms-conditions. For further
-** information use the contact form at https://www.qt.io/contact-us.
-**
-** GNU General Public License Usage
-** Alternatively, this file may be used under the terms of the GNU
-** General Public License version 3 or (at your option) any later version
-** approved by the KDE Free Qt Foundation. The licenses are as published by
-** the Free Software Foundation and appearing in the file LICENSE.GPL3
-** included in the packaging of this file. Please review the following
-** information to ensure the GNU General Public License requirements will
-** be met: https://www.gnu.org/licenses/gpl-3.0.html.
-**
-** $QT_END_LICENSE$
-**
-****************************************************************************/
+// Copyright (C) 2017 The Qt Company Ltd.
+// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR GPL-3.0-only
 
 #include <QtNetwork/qtnetwork-config.h>
 
@@ -44,8 +18,14 @@
 #include <QtNetwork/qnetworkaccessmanager.h>
 #include <QtNetwork/qhttpmultipart.h>
 
+#ifndef QT_NO_SSL
+#include <QtNetwork/qsslconfiguration.h>
+#endif
+
 QT_BEGIN_NAMESPACE
 
+using namespace Qt::StringLiterals;
+
 /*!
     \class QAbstractOAuth2
     \inmodule QtNetworkAuth
@@ -113,23 +93,23 @@ QT_BEGIN_NAMESPACE
     from the server.
 */
 
-using Key = QAbstractOAuth2Private::OAuth2KeyString;
-const QString Key::accessToken =        QStringLiteral("access_token");
-const QString Key::apiKey =             QStringLiteral("api_key");
-const QString Key::clientIdentifier =   QStringLiteral("client_id");
-const QString Key::clientSharedSecret = QStringLiteral("client_secret");
-const QString Key::code =               QStringLiteral("code");
-const QString Key::error =              QStringLiteral("error");
-const QString Key::errorDescription =   QStringLiteral("error_description");
-const QString Key::errorUri =           QStringLiteral("error_uri");
-const QString Key::expiresIn =          QStringLiteral("expires_in");
-const QString Key::grantType =          QStringLiteral("grant_type");
-const QString Key::redirectUri =        QStringLiteral("redirect_uri");
-const QString Key::refreshToken =       QStringLiteral("refresh_token");
-const QString Key::responseType =       QStringLiteral("response_type");
-const QString Key::scope =              QStringLiteral("scope");
-const QString Key::state =              QStringLiteral("state");
-const QString Key::tokenType =          QStringLiteral("token_type");
+using OAuth2 = QAbstractOAuth2Private::OAuth2KeyString;
+const QString OAuth2::accessToken =        u"access_token"_s;
+const QString OAuth2::apiKey =             u"api_key"_s;
+const QString OAuth2::clientIdentifier =   u"client_id"_s;
+const QString OAuth2::clientSharedSecret = u"client_secret"_s;
+const QString OAuth2::code =               u"code"_s;
+const QString OAuth2::error =              u"error"_s;
+const QString OAuth2::errorDescription =   u"error_description"_s;
+const QString OAuth2::errorUri =           u"error_uri"_s;
+const QString OAuth2::expiresIn =          u"expires_in"_s;
+const QString OAuth2::grantType =          u"grant_type"_s;
+const QString OAuth2::redirectUri =        u"redirect_uri"_s;
+const QString OAuth2::refreshToken =       u"refresh_token"_s;
+const QString OAuth2::responseType =       u"response_type"_s;
+const QString OAuth2::scope =              u"scope"_s;
+const QString OAuth2::state =              u"state"_s;
+const QString OAuth2::tokenType =          u"token_type"_s;
 
 QAbstractOAuth2Private::QAbstractOAuth2Private(const QPair<QString, QString> &clientCredentials,
                                                const QUrl &authorizationUrl,
@@ -233,7 +213,7 @@ QUrl QAbstractOAuth2::createAuthenticatedUrl(const QUrl &url, const QVariantMap
     }
     QUrl ret = url;
     QUrlQuery query(ret.query());
-    query.addQueryItem(Key::accessToken, d->token);
+    query.addQueryItem(OAuth2::accessToken, d->token);
     for (auto it = parameters.begin(), end = parameters.end(); it != end ;++it)
         query.addQueryItem(it.key(), it.value().toString());
     ret.setQuery(query);
@@ -506,6 +486,52 @@ void QAbstractOAuth2::setRefreshToken(const QString &refreshToken)
     }
 }
 
+#ifndef QT_NO_SSL
+/*!
+    \since 6.5
+
+    Returns the TLS configuration to be used when establishing a mutual TLS
+    connection between the client and the Authorization Server.
+
+    \sa setSslConfiguration(), sslConfigurationChanged()
+*/
+QSslConfiguration QAbstractOAuth2::sslConfiguration() const
+{
+    Q_D(const QAbstractOAuth2);
+    return d->sslConfiguration.value_or(QSslConfiguration());
+}
+
+/*!
+    \since 6.5
+
+    Sets the TLS \a configuration to be used when establishing
+    a mutual TLS connection between the client and the Authorization Server.
+
+    \sa sslConfiguration(), sslConfigurationChanged()
+*/
+void QAbstractOAuth2::setSslConfiguration(const QSslConfiguration &configuration)
+{
+    Q_D(QAbstractOAuth2);
+    const bool configChanged = !d->sslConfiguration || (*d->sslConfiguration != configuration);
+    if (configChanged) {
+        d->sslConfiguration = configuration;
+        Q_EMIT sslConfigurationChanged(configuration);
+    }
+}
+
+/*!
+    \fn void QAbstractOAuth2::sslConfigurationChanged(const QSslConfiguration &configuration)
+    \since 6.5
+
+    The signal is emitted when the TLS configuration has changed.
+    The \a configuration parameter contains the new TLS configuration.
+
+    \sa sslConfiguration(), setSslConfiguration()
+*/
+#endif // !QT_NO_SSL
+
 QT_END_NAMESPACE
 
+#include "moc_qabstractoauth2.cpp"
+
 #endif // QT_NO_HTTP
